@@ -21,6 +21,8 @@ import numpy as np
 import six
 import warnings
 from . import pixelfunc
+from . import sphtfunc
+from ._sphtools import rotate_alm
 
 coordname = {"G": "Galactic", "E": "Ecliptic", "C": "Equatorial"}
 
@@ -28,6 +30,7 @@ coordname = {"G": "Galactic", "E": "Ecliptic", "C": "Equatorial"}
 class ConsistencyWarning(Warning):
     """Warns for a problem in the consistency of data
     """
+
     pass
 
 
@@ -85,6 +88,7 @@ class Rotator(object):
     >>> print(vec_ecl)
     [-0.05488249 -0.99382103 -0.09647625]
     """
+
     ErrMessWrongPar = (
         "rot and coord must be single elements or " "sequence of same size."
     )
@@ -373,14 +377,60 @@ class Rotator(object):
         cosalpha = north_pole[2] - vp[2] * np.dot(north_pole, vp)
         return np.arctan2(sinalpha, cosalpha)
 
-    def rotate_map(self, m):
-        """Rotate a HEALPix map to a new reference frame
+    def rotate_alm(self, alm, lmax=None, mmax=None):
+        """Rotate Alms with the transform defined in the Rotator object
 
+        see the docstring of the rotate_alm function defined
+        in the healpy package, this function **returns** the rotated alms,
+        does not rotate in place"""
+
+        rotated_alm = alm.copy()  # rotate_alm works inplace
+        rotate_alm(rotated_alm, matrix=self.mat, lmax=lmax, mmax=mmax)
+        return rotated_alm
+
+    def rotate_map_alms(self, m, use_pixel_weights=True, lmax=None, mmax=None):
+        """Rotate a HEALPix map to a new reference frame in spherical harmonics space
+
+        This is generally the best strategy to rotate/change reference frame of maps.
+        If the input map is band-limited, i.e. it can be represented exactly by
+        a spherical harmonics transform under a specific lmax, the map rotation
+        will be invertible.
+
+
+        Parameters
+        ----------
+        m : np.ndarray
+            Input map, 1 map is considered I, 2 maps:[Q,U], 3 maps:[I,Q,U]
+        use_pixel_weights : bool, optional
+            Use pixel weights in map2alm
+
+        Returns
+        -------
+        m_rotated : np.ndarray
+            Map in the new reference frame
+        """
+        alm = sphtfunc.map2alm(
+            m, use_pixel_weights=use_pixel_weights, lmax=lmax, mmax=mmax
+        )
+        rotated_alm = self.rotate_alm(alm, lmax=lmax, mmax=mmax)
+        return sphtfunc.alm2map(
+            rotated_alm, lmax=lmax, mmax=mmax, nside=pixelfunc.get_nside(m)
+        )
+
+    def rotate_map_pixel(self, m):
+        """Rotate a HEALPix map to a new reference frame in pixel space
+
+        It is generally better to rotate in spherical harmonics space, see
+        the rotate_map_alms method. A case where pixel space rotation is
+        better is for heavily masked maps where the spherical harmonics
+        transform is not well defined.
         This function first rotates the pixels centers of the new reference
         frame to the original reference frame, then uses hp.get_interp_val
         to interpolate bilinearly the pixel values, finally fixes Q and U
         polarization by the modification to the psi angle caused by
         the Rotator using Rotator.angle_ref.
+        Due to interpolation, this function generally suppresses the signal at
+        high angular scales.
 
         Parameters
         ----------
