@@ -15,7 +15,6 @@ warnings.filterwarnings("ignore")
 
 
 class TestSphtFunc(unittest.TestCase):
-
     def setUp(self):
         self.lmax = 64
         self.path = os.path.dirname(os.path.realpath(__file__))
@@ -273,6 +272,20 @@ class TestSphtFunc(unittest.TestCase):
             # FIXME: rtol=1e-6 works here, except on Debian with Python 3.4.
             np.testing.assert_allclose(i, o, rtol=1e-5)
 
+    def test_rotate_alm_rotmatrix(self):
+        """rotate_alm also support rotation matrix instead of angles"""
+        lmax = 32
+        nalm = hp.Alm.getsize(lmax)
+        alm = np.zeros([3, nalm], dtype=np.complex)
+        alm[0, 1] = 1
+        alm[1, 2] = 1
+        alm_rotated_angles = alm.copy()
+        angles = hp.rotator.coordsys2euler_zyz(coord=["G", "E"])
+        hp.rotate_alm(alm_rotated_angles, *angles)
+        gal2ecl = hp.Rotator(coord=["G", "E"])
+        hp.rotate_alm(alm, matrix=gal2ecl.mat)
+        np.testing.assert_allclose(alm_rotated_angles, alm)
+
     def test_rotate_alm2(self):
         # Test rotate_alm against the Fortran library
         lmax = 64
@@ -381,6 +394,18 @@ class TestSphtFunc(unittest.TestCase):
         beam = hp.bl2beam(gaussian_window, theta)
         np.testing.assert_allclose(gaussian_beam, beam, rtol=1e-3)
 
+    def test_max_nside_check(self):
+        """ Test whether the max_nside_check correctly raises ValueErrors for nsides
+        that are too large."""
+
+        # Test an nside that is too large
+        with self.assertRaises(ValueError):
+            hp.check_max_nside(16384)
+        
+        # Test an nside that is valid
+        # hp.check_max_nside will return 0 if no exceptions are raised
+        self.assertEqual(hp.check_max_nside(1024), 0)
+
 
 if __name__ == "__main__":
     unittest.main()
